<?php
/**
 * WARNING: This file is part of the theme. DO NOT edit
 * this file under any circumstances.
 */

/**
 * Prevent direct access to this file
 */
defined( 'ABSPATH' ) or die();

/**
 * @package  Anycar
 * @author   Binh Pham Thanh <binhpham@linethemes.com>
 */
class Anycar_PageOptions extends Anycar_Base
{
	protected function __construct() {
		add_action( 'admin_init', array( $this, 'register' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
	}

	public function admin_enqueue_scripts( $hook ) {
		if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) && current_post_type_is( 'page' ) ) {
			wp_enqueue_script( 'anycar-page-options' );
		}
	}

	/**
	 * Register page options controls
	 * 
	 * @return  void
	 */
	public function register() {
		global $wp_registered_sidebars;

		$patterns = predefined_background_patterns();
		$options  = array();
		$sidebars = array();

		// Retrieve all registered sidebars
		foreach( $wp_registered_sidebars as $params )
			$sidebars[$params['id']] = $params['name'];

		/**
		 * General
		 */
		$options['layout_heading'] = array(
			'type' => 'heading',
			'section' => 'all',
			'title' => __( 'Sidebar Position', 'anycar' ),
			'description' => __( 'Select the position of sidebar that you wish to display.', 'anycar' )
		);

		$options['sidebar_layout'] = array(
			'type' => 'dropdown',
			'section' => 'all',
			'default' => 'default',
			'choices' => array(
				'default' => __( 'Default Option', 'anycar' ),
				'no-sidebar'   => __( 'No Sidebar', 'anycar' ),
				'sidebar-left'  => __( 'Left Sidebar', 'anycar' ),
				'sidebar-right'  => __( 'Right Sidebar', 'anycar' ),
			)
		);

		$options['sidebar_default'] = array(
			'type'    => 'dropdown-sidebars',
			'label'   => __( 'Custom Sidebar', 'anycar' ),
			'section' => 'all',
			'default' => op_option( 'sidebar_default' )
		);
		
		/**
		 * Page Title
		 */
		$options['pagetitle_heading'] = array(
			'type'        => 'heading',
			'section'     => 'all',
			'title'       => __( 'Page Title', 'anycar' ),
			'description' => __( 'In this section you can turn on/off or modify style for the Page Title.', 'anycar' )
		);

		$options['enable_custom_page_header'] = array(
			'type'    => 'switcher',
			'label'   => __( 'Enable Custom Page Title', 'anycar' ),
			'section' => 'all',
			'default' => false
		);

		$options['pagetitle_enabled'] = array(
			'type'    => 'switcher',
			'label'   => __( 'Display Title Bar On This Page', 'anycar' ),
			'section' => 'all',
			'default' => op_option( 'pagetitle_enabled' )
		);

		$options['pagetitle_background'] = array(
			'type'     => 'background',
			'label'    => __( 'Page Header Background', 'anycar' ),
			'section'  => 'all',
			'patterns' => $patterns,
			'default'  => op_option( 'pagetitle_background' )
		);

		/**
		 * Breadcrumbs
		 */
		$options['breadcrumb_heading'] = array(
			'type'        => 'heading',
			'section'     => 'all',
			'title'       => __( 'Breadcrumbs', 'anycar' ),
			'description' => __( 'In this section you can turn on/off or modify style for the Breadcrumbs.', 'anycar' )
		);

		$options['breadcrumb_enabled'] = array(
			'type' => 'dropdown',
			'section' => 'all',
			'default' => 'default',
			'choices' => array(
				'default' => __( 'Default Option', 'anycar' ),
				'enable'   => __( 'Enabled', 'anycar' ),
				'disable'  => __( 'Disabled', 'anycar' ),
			)
		);

		/**
		 * Header
		 */
		$options['topbar_heading'] = array(
			'type' => 'heading',
			'section' => 'all',
			'title' => __( 'Top Bar', 'anycar' ),
			'description' => __( 'Turn on/off the top bar and change it styles.', 'anycar' )
		);

		$options['topbar_enabled'] = array(
			'type' => 'dropdown',
			'section' => 'all',
			'default' => 'default',
			'choices' => array(
				'default' => __( 'Default Option', 'anycar' ),
				'enable'   => __( 'Enabled', 'anycar' ),
				'disable'  => __( 'Disabled', 'anycar' ),
			)
		);

		$options['navigator_heading'] = array(
			'type'        => 'heading',
			'section'     => 'all',
			'title'       => __( 'Navigator', 'anycar' ),
			'description' => __( 'Just select your menu that you wish assign it to the location on the theme.', 'anycar' )
		);

		// Navigator
		$menus     = wp_get_nav_menus();
		$locations = get_registered_nav_menus();

		if ( $menus ) {
			$choices = array( 'default' => __( 'Default Option', 'anycar' ) );
			foreach ( $menus as $menu ) {
				$choices[ $menu->term_id ] = wp_html_excerpt( $menu->name, 40, '&hellip;' );
			}

			$asigned_locations = op_option( 'nav_menu_locations' );

			foreach ( $locations as $location => $description ) {
				$menu_setting_id = "nav_menu_locations[{$location}]";

				$options["menu_location_{$location}"] = array(
					'label'   => $description,
					'section' => 'all',
					'type'    => 'dropdown',
					'choices' => $choices,
					'default' => 'default'
				);
			}
		}

		$options['onepage_nav_script'] = array(
			'type'    => 'switcher',
			'label'   => __( 'Load One Page Navigator Script', 'anycar' ),
			'section' => 'all',
			'default' => false
		);

		new \OptionsPlus\Metabox\Properties( 'page-options', array(
			'label'       => __( 'Page Options', 'anycar' ),
			'post_types'  => 'page',
			'context'     => 'normal',
			'priority'    => 'high',
			'storage_key' => '_page_options',
			'show_tabs'   => false,
			'sections'    => array(
				'all'     => array( 'title' => __( 'General', 'anycar' ) )
			),
			'options'     => $options
		) );
	}
}
